/**
 * Repraesentation einer Klausur mit einem Titel und einer Liste von angemeldeten
 * Studenten.
 * 
 * @author Annabelle Klarl
 * 
 */
public class Klausur {
    private String titel;
    private Student[] teilnehmer;
    private int anzahlAngemeldete;

    /**
     * Konstruktor
     * 
     * @param titel
     *            Titel der Klausur
     * @param maxTeilnehmer
     *            maximale Anzahl an Teilnehmern
     */
    public Klausur(String titel, int maxTeilnehmer) {
        this.titel = titel;
        this.teilnehmer = new Student[maxTeilnehmer];
        this.anzahlAngemeldete = 0;
    }

    /**
     * Diese Methode liefert den Titel der Klausur
     * 
     * @return
     */
    public String getTitel() {
        return this.titel;
    }

    /**
     * Diese Methode meldet einen Studenten mit der gegebenen Matrikelnummer und
     * dem gegebenen Namen an. Dazu wird zunaechst ein neues Objekt der Klasse
     * {@link Student} erzeugt, dieser an der Klausur angemeldet und true
     * zurueckgegeben. Ist die Klausur schon voll (d.h. wird die Maximalanzahl an
     * Teilnehmern ueberschritten), wird der Student nicht angemeldet und false
     * zurueckgegeben.
     * 
     * @param matrNr
     * @param name
     * @return false falls die Maximalanzahl an Teilnehmern ueberschritten wurde,
     *         true sonst
     */
    public boolean anmelden(int matrNr, String name) {
        if (this.anzahlAngemeldete < this.teilnehmer.length) {
            this.teilnehmer[this.anzahlAngemeldete] = new Student(
                    matrNr, name);
            this.anzahlAngemeldete++;
            return true;
        }
        return false;
    }

    /**
     * Diese Methode sucht in der Liste an Teilnehmern der Klausur einen
     * Studenten mit der gegebenen Matrikelnummer. Wird ein Student gefunden,
     * wird dieser zurueckgegeben. Falls kein Student mit dieser Matrikelnummer
     * angemeldet ist, wird null zurueckgegeben.
     * 
     * @param matrNr
     * @return das Objekt der Klasse Student mit der gegebenen Matrikelnummer;
     *         null falls kein Student mit dieser Matrikelnummer gefunden wird.
     */
    public Student sucheStudent(int matrNr) {
        for (int i = 0; i < this.anzahlAngemeldete; i++) {
            Student aktuellerStudent = this.teilnehmer[i];
            if (aktuellerStudent.getMatrNr() == matrNr) {
                return aktuellerStudent;
            }
        }
        return null;
    }

    /**
     * Diese Methode traegt fuer einen Studenten mit der gegebenen Matrikelnummer
     * die gegebene Note ein. Falls ein Student mit dieser Matrikelnummer an der
     * Klausur angemeldet ist, wird die Note eingetragen und true zurueckgegeben.
     * Falls kein Student angemeldet ist, wird false zurueckgegeben.
     * 
     * @param matrNr
     * @param note
     * @return true falls ein Student mit der gegebenen Matrikelnummer an der
     *         Klausur angemeldet ist (und die Note eingetragen wurde); false
     *         sonst
     */
    public boolean noteEintragen(int matrNr, double note) {
        Student student = this.sucheStudent(matrNr);
        if (student != null) {
            student.setNote(note);
            return true;
        }
        return false;
    }
}
